@@ -1,11 +1,12 @@
 from typing import Literal
 from dataclasses import dataclass, field
+import robust_extraction2 as re
 from moveread.core import Image, Rectangle
 
 @dataclass
 class ImgOutput:
   img: str
-  meta: Image.Meta = field(default_factory=Image.Meta)
+  meta: Image.Meta = field(default_factory=Image.Meta) # type: ignore
 
 @dataclass
 class Output:
@@ -16,7 +17,7 @@ class Output:
 @dataclass
 class BaseInput:
   img: str
-  model: str
+  model: re.ExtendedModel
 
 @dataclass
 class Uncorrected(BaseInput):
@@ -25,6 +26,7 @@ class Uncorrected(BaseInput):
 @dataclass
 class BaseCorrected(BaseInput):
   corrected: str
+  perspective: re.Perspective | None
 
 @dataclass
 class Corrected(BaseCorrected):
