@@ -2,6 +2,7 @@ from typing import Literal, Any
 from dataclasses import dataclass
 from haskellian import either as E
 from pipeteer import ReadQueue, WriteQueue, Task
+from pipeteer.queues import ReadError
 
 @dataclass
 class Input:
@@ -18,7 +19,7 @@ class ValidateAPI:
   def items(self):
     return self.Qin.items()
   
-  @E.do()
+  @E.do[ReadError]()
   async def annotate(self, id: str, annotation: Annotation):
     (await self.Qin.read(id)).unsafe()
     (await self.Qout.push(id, annotation)).unsafe() # type: ignore
