@@ -3,7 +3,9 @@ from argparse import ArgumentParser
 def main():
   parser = ArgumentParser()
   parser.add_argument('-q', '--queues', required=True)
-  parser.add_argument('--images', required=True)
+  parser.add_argument('--images', required=True, help='Connection string to images')
+  parser.add_argument('--url', required=True, help='The server URL')
+  parser.add_argument('--height', default=768, type=int, help='Height of descaled images')
 
   parser.add_argument('-p', '--port', default=8000, type=int)
   parser.add_argument('--host', default='0.0.0.0', type=str)
@@ -13,35 +15,35 @@ def main():
   import os
   from dslog import Logger
   queues_path = os.path.join(os.getcwd(), args.queues)
-  images_path = os.path.join(os.getcwd(), args.images)
   
   logger = Logger.click().prefix('[PREPROCESS]')
   logger(f'Running preprocessing...')
-  logger(f'Images path: "{images_path}"')
+  logger(f'Images connection string: "{args.images}"')
   logger(f'Queues path: "{queues_path}"')
   
-  from typing import Sequence
   import asyncio
-  from functools import cache
   from multiprocessing import Process
-  from kv import FilesystemKV
+  from kv import KV, ServerKV, LocatableKV
   import uvicorn
   from fastapi.middleware.cors import CORSMiddleware
   from pipeteer import QueueKV
   from moveread.pipelines.preprocess import Preprocess, Output
 
-  @cache
-  def get_queue(path: Sequence[str], type: type):
-    return QueueKV.sqlite(type, queues_path, table='-'.join(path))
+  def get_queue(path, type: type):
+    return QueueKV.sqlite(type, queues_path, table='-'.join(['queue', *path]))
   
-  blobs = FilesystemKV[bytes](images_path)
+  images = locatable_imgs = KV[bytes].of(args.images)
+  if not isinstance(locatable_imgs, LocatableKV):
+    locatable_imgs = images.served(args.url.rstrip('/') + '/images')
+
   Qout = get_queue(('output',), Output)
 
   wkf = Preprocess()
-  params = Preprocess.Params(logger=logger, blobs=blobs, images_path=images_path)
+  params = Preprocess.Params(logger=logger, images=locatable_imgs, descaled_h=args.height)
   Qs = wkf.connect(Qout, get_queue, params)
   artifacts = wkf.run(Qs, params)
   artifacts.api.add_middleware(CORSMiddleware, allow_origins=['*'], allow_credentials=True, allow_methods=['*'], allow_headers=['*'])
+  artifacts.api.mount('/images', ServerKV(images))
 
   ps = {
     id: Process(target=asyncio.run, args=(f,)) for id, f in artifacts.processes.items()
@@ -57,6 +59,6 @@ def main():
 if __name__ == '__main__':
   import sys
   import os
-  os.chdir('/home/m4rs/mr-github/rnd/dfy-pipeline/preprocess/dev/demo')
+  os.chdir('/home/m4rs/mr-github/rnd/pipelines/preprocess/dev/demo')
   sys.argv.extend('-q queues.sqlite --images images'.split(' '))
   main()
\ No newline at end of file
