@@ -4,13 +4,14 @@ from haskellian import either as E
 from kv import KV
 from dslog import Logger
 from pipeteer import WriteQueue
+import robust_extraction2 as re
 from moveread.core import Core, Game
 from moveread.pipelines.preprocess import Input
 
 async def input_core(
   core: Core, Qin: WriteQueue[Input],
   *, images: KV[bytes],
-  model_fn: Callable[[Game], str] = lambda *_: 'llobregat23',
+  model_fn: Callable[[Game], 're.ExtendedModel'],
   num_games: int | None = None, shuffle: bool = True,
   logger = Logger.rich().prefix('[CORE INPUT]')
 ):
@@ -26,7 +27,7 @@ async def input_core(
   for gameId in games[:num_games]:
     game = (await core.games.read(gameId)).unsafe()
     for imgId, image in game.images:
-      id = '-'.join(map(str, imgId))
+      id = '-'.join([gameId, *map(str, imgId)])
       url = f'{id}/original_{uuid4()}.jpg'
       img = (await core.blobs.read(image.url)).unsafe()
       (await images.insert(url, img)).unsafe()
